@@ -202,35 +202,14 @@ load_cache (ECalBackendExchange *cbex, E2kUri *e2kuri, GError **perror)
 		user_cache_dir, "calendar", mangled_uri, NULL);
 	storage_dir = g_path_get_dirname (cbex->priv->object_cache_file);
 
-	if (g_lstat(cbex->priv->local_attachment_store , &buf) < 0) {
+	if (g_lstat (cbex->priv->local_attachment_store , &buf) < 0) {
 #ifdef G_OS_UNIX
-		gint failed = TRUE;
-
- again:
 		if (symlink (storage_dir, cbex->priv->local_attachment_store) < 0)
 			g_warning ("%s: symlink() failed: %s", G_STRFUNC, g_strerror (errno));
-		else
-			failed = FALSE;
-
-		if (failed) {
-			gchar *parent_dir = g_build_filename (user_cache_dir, "calendar", NULL);
-
-			if (!g_file_test (parent_dir, G_FILE_TEST_IS_DIR)) {
-				g_mkdir_with_parents (parent_dir, 0700);
-				g_free (parent_dir);
-
-				failed = FALSE;
-				goto again;
-			}
-
-			g_free (parent_dir);
-		}
 #else
 		g_warning ("should symlink %s->%s, huh?",
 			   cbex->priv->local_attachment_store,
 			   storage_dir);
-
-		g_mkdir_with_parents (cbex->priv->local_attachment_store, 0700);
 #endif
 	}
 	g_free (storage_dir);
@@ -1476,7 +1455,7 @@ set_mode (ECalBackend *backend, CalMode mode)
 			priv->mode = CAL_MODE_REMOTE;
 
 			if (is_loaded (backend) && re_open)
-				e_cal_backend_notify_auth_required(backend);
+				e_cal_backend_notify_auth_required (backend);
 			break;
 
 	case CAL_MODE_LOCAL:
@@ -1741,22 +1720,12 @@ save_attach_file (const gchar *dest_file, gchar *file_contents, gint len)
 
 	/* Write it to our local exchange store. */
 	fd = g_open (dest_file, O_RDWR | O_CREAT | O_TRUNC | O_BINARY, 0600);
-	if (fd < 0) {
-		gchar *dir = g_path_get_dirname (dest_file);
-
-		if (dir && (dir[0] != '.' || !dir[1]) &&
-		    g_mkdir_with_parents (dir, 0700) >= 0)
-			fd = g_open (dest_file, O_RDWR | O_CREAT | O_TRUNC | O_BINARY, 0600);
-
-		g_free (dir);
-	}
-
 	if (fd < 0) {
 		d(printf ("open of destination file for attachments failed\n"));
 		goto end;
 	}
 
-	if (camel_write (fd, file_contents, len, NULL) < 0) {
+	if (camel_write (fd, file_contents, len, NULL, NULL) < 0) {
 		d(printf ("camel write to attach file failed\n"));
 		goto end;
 	}
@@ -1765,10 +1734,6 @@ save_attach_file (const gchar *dest_file, gchar *file_contents, gint len)
 
 end :
 	close (fd);
-
-	if (!dest_url)
-		g_warning ("Failed to save attachment to file '%s', directory does not exist/disk full?", dest_file);
-
 	return dest_url;
 }
 
@@ -1789,7 +1754,8 @@ get_attachment (ECalBackendExchange *cbex, const gchar *uid,
 
 	stream = camel_stream_mem_new_with_buffer (body, len);
 	msg = camel_mime_message_new ();
-	camel_data_wrapper_construct_from_stream (CAMEL_DATA_WRAPPER (msg), stream, NULL);
+	camel_data_wrapper_construct_from_stream_sync (
+		CAMEL_DATA_WRAPPER (msg), stream, NULL, NULL);
 	g_object_unref (stream);
 
 	msg_content = camel_medium_get_content (CAMEL_MEDIUM (msg));
@@ -1806,18 +1772,15 @@ get_attachment (ECalBackendExchange *cbex, const gchar *uid,
 
 				byte_array = g_byte_array_new ();
 				stream = camel_stream_mem_new_with_byte_array (byte_array);
-				camel_data_wrapper_decode_to_stream (content, stream, NULL);
+				camel_data_wrapper_decode_to_stream_sync (content, stream, NULL, NULL);
 				attach_data = g_memdup (byte_array->data, byte_array->len);
 				attach_file = g_strdup_printf ("%s/%s-%s", cbex->priv->local_attachment_store, uid, filename);
 				// Attach
 				attach_file_url = save_attach_file (attach_file, (gchar *) attach_data, byte_array->len);
 				g_free (attach_data);
 				g_free (attach_file);
-
-				if (attach_file_url) {
-					d(printf ("attach file name : %s\n", attach_file_url));
-					list = g_slist_append (list, attach_file_url);
-				}
+				d(printf ("attach file name : %s\n", attach_file_url));
+				list = g_slist_append (list, attach_file_url);
 
 				g_object_unref (stream);
 			}
@@ -1849,7 +1812,7 @@ get_attach_file_contents (const gchar *filename, gint *length)
 	if (len > 0) {
 		file_contents = g_malloc0 (len + 1);
 
-		if (camel_read (fd, file_contents, len, NULL) < 0) {
+		if (camel_read (fd, file_contents, len, NULL, NULL) < 0) {
 			d(printf ("reading from the attachment file failed\n"));
 			g_free (file_contents);
 			file_contents = NULL;
@@ -1883,7 +1846,7 @@ process_delegated_cal_object (icalcomponent *icalcomp, const gchar *delegator_na
 			if (text && (!g_ascii_strcasecmp (delegatee_email, text) || !g_ascii_strcasecmp (delegator_email, text))) {
 				icalproperty_set_organizer (prop, g_strdup_printf ("MAILTO:%s", delegator_email));
 				icalproperty_remove_parameter_by_kind (prop, ICAL_CN_PARAMETER);
-				icalproperty_add_parameter (prop, icalparameter_new_cn (g_strdup(delegator_name)));
+				icalproperty_add_parameter (prop, icalparameter_new_cn (g_strdup (delegator_name)));
 				icalproperty_remove_parameter_by_kind (prop, ICAL_SENTBY_PARAMETER);
 				icalproperty_add_parameter (prop, icalparameter_new_sentby (g_strdup_printf("MAILTO:%s", delegatee_email)));
 			}
@@ -1909,7 +1872,7 @@ process_delegated_cal_object (icalcomponent *icalcomp, const gchar *delegator_na
 		text = g_strstrip (text);
 		if (text && !g_ascii_strcasecmp (delegator_email, text)) {
 			icalproperty_remove_parameter_by_kind (prop, ICAL_CN_PARAMETER);
-			icalproperty_add_parameter (prop, icalparameter_new_cn (g_strdup(delegator_name)));
+			icalproperty_add_parameter (prop, icalparameter_new_cn (g_strdup (delegator_name)));
 			icalproperty_remove_parameter_by_kind (prop, ICAL_SENTBY_PARAMETER);
 			icalproperty_add_parameter (prop, icalparameter_new_sentby (g_strdup_printf("MAILTO:%s", delegatee_email)));
 			g_free (text);
@@ -1965,22 +1928,12 @@ receive_attachments (ECalBackendExchange *cbex, ECalComponent *comp)
 
 	e_cal_component_get_attachment_list (comp, &attach_list);
 	for (l = attach_list; l; l = l->next) {
-		const gchar *fname;
-		gchar *dest_url, *attach_file = NULL, *file_contents, *old_file = NULL;
+		gchar *fname, *dest_url, *attach_file = NULL, *file_contents;
 		gint len = 0;
 
 		if (!strncmp ((gchar *)l->data, "file://", 7)) {
-			attach_file = g_filename_from_uri ((gchar *)l->data, NULL, NULL);
-			fname = attach_file;
-
-			if (fname && cbex->priv->local_attachment_store && !g_str_has_prefix (fname, cbex->priv->local_attachment_store)) {
-				/* it's not in our store, thus save it there */
-				gchar *base_name = g_path_get_basename (attach_file);
-
-				old_file = attach_file;
-				attach_file = g_build_filename (cbex->priv->local_attachment_store, uid, base_name, NULL);
-				g_free (base_name);
-			}
+			fname = g_filename_from_uri ((gchar *)l->data, NULL, NULL);
+			attach_file = fname;
 		} else {
 			const gchar *filename;
 
@@ -1998,7 +1951,6 @@ receive_attachments (ECalBackendExchange *cbex, ECalComponent *comp)
 
 		/* attach_file should be g_freed */
 		file_contents = get_attach_file_contents (fname, &len);
-		g_free (old_file);
 		if (!file_contents) {
 			g_free (attach_file);
 			continue;
@@ -2035,7 +1987,7 @@ build_msg ( ECalBackendExchange *cbex, ECalComponent *comp, const gchar *subject
 	gchar *fname, *file_contents = NULL, *filename, *dest_url, *mime_filename, *attach_file;
 	gint len = 0;
 
-	if (!g_ascii_strcasecmp(e_cal_backend_exchange_get_owner_email (E_CAL_BACKEND_SYNC (cbex)), exchange_account_get_email_id (cbex->account)))
+	if (!g_ascii_strcasecmp (e_cal_backend_exchange_get_owner_email (E_CAL_BACKEND_SYNC (cbex)), exchange_account_get_email_id (cbex->account)))
 		e_cal_backend_exchange_get_from (E_CAL_BACKEND_SYNC (cbex), comp, &from_name, &from_email);
 	else
 		e_cal_backend_exchange_get_sender (E_CAL_BACKEND_SYNC (cbex), comp, &from_name, &from_email);
@@ -2062,7 +2014,7 @@ build_msg ( ECalBackendExchange *cbex, ECalComponent *comp, const gchar *subject
 		if (!strncmp ((gchar *)l->data, "file://", 7)) {
 			fname = g_filename_from_uri ((gchar *)l->data, NULL, NULL);
 			filename = g_path_get_basename (fname);
-			mime_filename = g_strdup (filename + strlen(uid) + 1);
+			mime_filename = g_strdup (filename + strlen (uid) + 1);
 			g_free (filename);
 			attach_file = fname;
 		} else {
@@ -2099,7 +2051,8 @@ build_msg ( ECalBackendExchange *cbex, ECalComponent *comp, const gchar *subject
 		/* Content */
 		stream = camel_stream_mem_new_with_buffer (file_contents, len);
 		wrapper = camel_data_wrapper_new ();
-		camel_data_wrapper_construct_from_stream (wrapper, stream, NULL);
+		camel_data_wrapper_construct_from_stream_sync (
+			wrapper, stream, NULL, NULL);
 		g_object_unref (stream);
 
 		mime_type = get_mime_type (dest_url);
@@ -2139,9 +2092,9 @@ build_msg ( ECalBackendExchange *cbex, ECalComponent *comp, const gchar *subject
 	byte_array = g_byte_array_new ();
 	stream = camel_stream_mem_new_with_byte_array (byte_array);
 	dw = camel_medium_get_content (CAMEL_MEDIUM (msg));
-	camel_data_wrapper_decode_to_stream (dw, stream, NULL);
-	g_byte_array_append (byte_array, (guint8 *) "", 1);
+	camel_data_wrapper_decode_to_stream_sync (dw, stream, NULL, NULL);
 	buffer = g_memdup (byte_array->data, byte_array->len);
+	buffer[byte_array->len] = '\0';
 	d(printf ("|| Buffer: \n%s\n", buffer));
 	g_object_unref (stream);
 	g_object_unref (msg);
